<?php

/**
 * Zend Framework (http://framework.zend.com/)
 *
 * @link      http://github.com/zendframework/ZendSkeletonApplication for the canonical source repository
 * @copyright Copyright (c) 2005-2014 Zend Technologies USA Inc. (http://www.zend.com)
 * @license   http://framework.zend.com/license/new-bsd New BSD License
 */

namespace Certificados;

use Certificados\Auth\Adapter;
use Certificados\Service\EmissaoService;
//use Certificados\Util\Util;
//use Certificados\View\Helper\Encrypt;
//use Certificados\View\Helper\FormataCPF;
//use Certificados\View\Helper\UserIdentity;
use Zend\Authentication\AuthenticationService;
use Zend\Authentication\Storage\Session as SessionStorage;
use Zend\ModuleManager\ModuleManager;
use Zend\Mvc\ModuleRouteListener;
use Zend\Mvc\MvcEvent;

class Module {

    public function onBootstrap(MvcEvent $e) {
        $eventManager = $e->getApplication()->getEventManager();
        $moduleRouteListener = new ModuleRouteListener();
        $moduleRouteListener->attach($eventManager);
    }

    public function getConfig() {
        return include __DIR__ . '/config/module.config.php';
    }

    public function getAutoloaderConfig() {
        return array(
            'Zend\Loader\StandardAutoloader' => array(
                'namespaces' => array(
                    __NAMESPACE__ => __DIR__ . '/src/' . __NAMESPACE__,
                ),
            ),
        );
    }

    public function getServiceConfig() {
        return array(
            'factories' => array(
                'Certificados\Service\EmissaoService' => function($sm) {
                    return new EmissaoService($sm->get('Doctrine\ORM\EntityManager'));
                },
                'Certificados\Auth\Adapter' => function($em) {
                    return new Adapter($em->get('Doctrine\ORM\EntityManager'));
                },
                'Certificados\Util\Util' => function($em) {
                    return new Adapter($em->get('Doctrine\ORM\EntityManager'));
                }
            )
        );
    }

    public function getViewHelperConfig() {
        return array(
            'invokables' => array(
                'formataCPF' => 'Certificados\View\Helper\FormataCPF',
                'UserIdentity' => 'Certificados\View\Helper\UserIdentity',
                'Encrypt' => 'Certificados\View\Helper\Encrypt',
            ),
        );
    }

    public function init(ModuleManager $moduleManager) {
        $sharedEvents = $moduleManager->getEventManager()->getSharedManager();
        $sharedEvents->attach('Zend\Mvc\Controller\AbstractActionController', MvcEvent::EVENT_DISPATCH, array($this, 'verificaAutenticacao'), 100);
    }

    public function verificaAutenticacao($e) {
        $auth = new AuthenticationService;
        $auth->setStorage(new SessionStorage("EMISSAO_CERTIFICADOS"));
        $controller = $e->getTarget();
        $matchedRoute = $controller->getEvent()->getRouteMatch()->getMatchedRouteName();
        if (!$auth->hasIdentity()) {
            if ((($matchedRoute == "certificados/emissao") || ($matchedRoute == "certificados/consulta-interna") || ($matchedRoute == "certificados/emissao-manual")) and $matchedRoute != "certificados/login") {
                return $controller->redirect()->toRoute("certificados/login");
            }
        }

        /**
         * IMPLEMENTAR CONTROLE DE ACESSO
         * 
         * NÃO PERMITIR ACESSAR EVENTOS DISPONÍVEIS PARA EMISSÃO ATRAVÉS DA URL
         *    - VERIFICAR SE O EVENTO ESTÁ DISPONÍVEL PARA EMISSÃO PRO USUÁRIO CORRENTE.
         */
    }

}
