<?php

namespace Certificados\Controller;

use Certificados\Util\Util;
use DOMPDFModule\View\Model\PdfModel;
use Zend\Authentication\AuthenticationService;
use Zend\Authentication\Storage\Session as SessionStorage;
use Zend\Mvc\Controller\AbstractActionController;
use Zend\Paginator\Adapter\ArrayAdapter;
use Zend\Paginator\Paginator;
use Zend\View\Model\ViewModel;

class ConsultaInternaController extends AbstractActionController {

    protected $em;

    protected function getEm() {
        if (null === $this->em) {
            $this->em = $this->getServiceLocator()->get('Doctrine\ORM\EntityManager');
        }
        return $this->em;
    }

    public function indexAction() {
        $auth = new AuthenticationService;
        $auth->setStorage(new SessionStorage("EMISSAO_CERTIFICADOS"));
        $pessoa = $auth->getIdentity();
        $eventos = $this->getEm()->getRepository('Certificados\Entity\Comissao')->findEventosCoordenadosByPessoa($pessoa->getPessoaId());
        return new ViewModel(array('eventos' => $eventos));
    }

    public function expandirEventoAction() {
        $id_crypt = $this->params()->fromRoute('id', '0');
        $id = Util::decrypt($id_crypt);
        if ($id) {
            $certificados = $this->getEm()->getRepository('Certificados\Entity\Certificado')->findByEvento($id);
        } else {
            $this->redirect()->toRoute('certificados/consulta-interna');
        }
        return new ViewModel(array('certificados' => $certificados, 'id' => $id));
    }

    public function imprimirAction() {
        $id_crypt = $this->params()->fromRoute('id', '0');
        $id = Util::decrypt($id_crypt);
        if ($id) {
            $certificados = $this->getEm()->getRepository('Certificados\Entity\Certificado')->findByEvento($id);
            if ($certificados) {
                $paginator = new Paginator(new ArrayAdapter($certificados));
                $paginator->setItemCountPerPage(12);
                $pdf = new PdfModel();
                $pdf->setOption('paperSize', 'a4');
                $pdf->setOption('paperOrientation', 'landscape');
                $pdf->setVariables(array(
                    'certificados' => $certificados,
                    'paginator' => $paginator
                ));
                return $pdf;
            } else {
                return $this->redirect()->toRoute("certificados/consulta-interna", array('action' => 'index'));
            }
        }
        return $this->redirect()->toRoute("certificados/consulta-interna", array('action' => 'index'));
    }

}
