<?php

namespace Certificados\Controller;

use Certificados\Util\Util;
use Zend\Authentication\AuthenticationService;
use Zend\Authentication\Storage\Session as SessionStorage;
use Zend\Mvc\Controller\AbstractActionController;
use Zend\View\Model\ViewModel;

class EmissaoController extends AbstractActionController {

    protected $em;

    protected function getEm() {
        if (null === $this->em) {
            $this->em = $this->getServiceLocator()->get('Doctrine\ORM\EntityManager');
        }
        return $this->em;
    }

    public function indexAction() {
        $auth = new AuthenticationService;
        $auth->setStorage(new SessionStorage("EMISSAO_CERTIFICADOS"));
        $pessoa = $auth->getIdentity();
        $eventos_disponiveis = $this->getEm()->getRepository('Certificados\Entity\Comissao')->findEventosDisponiveisByPessoa($pessoa->getPessoaId());
        return new ViewModel(array('eventos' => $eventos_disponiveis["eventos"], 'pessoa' => $eventos_disponiveis["pessoa"]));
    }

    public function listarParticipantesAction() {
        $auth = new AuthenticationService;
        $auth->setStorage(new SessionStorage("EMISSAO_CERTIFICADOS"));
        $pessoa = $auth->getIdentity();

        $id_crypt = $this->params()->fromRoute('id', '0');
        $id = Util::decrypt($id_crypt);
        $evento = $this->getEm()->getRepository('Certificados\Entity\Evento')->findOneByEventoId($id);

        if ($evento) {
            if ($this->permitidoAcessar($pessoa, $evento)) {
                if ($evento->getEveDisponivelEmissao()) {
                    $inscricoes = $this->getEm()->getRepository('Certificados\Entity\Inscricao')->findInscricoesCredenciadas($evento);
                    $colaboradores = $this->getEm()->getRepository('Certificados\Entity\Comissao')->findColaboradores($evento);
                    $organizadores = $this->getEm()->getRepository('Certificados\Entity\Comissao')->findCoordenadores($evento);
                    $eventos_secundarios = $this->getEm()->getRepository('Certificados\Entity\EventoSecundario')->findByEvento($evento->getEventoId());
//            $ministrantes = $this->getEm()->getRepository('Certificados\Entity\Comissao')->findCoordenadores($evento); IMPLEMENTAR
                } else {
                    return $this->redirect()->toRoute("certificados/emissao");
                }
            } else {
                $this->redirect()->toRoute("certificados/emissao");
            }
            return new ViewModel(array('inscricoes' => $inscricoes, 'evento' => $evento, 'eventos_secundarios' => $eventos_secundarios, 'colaboradores' => $colaboradores, 'organizadores' => $organizadores));
        } else {
            return new ViewModel(array('erro' => true));
        }
    }

    public function emitirAction() {
        $auth = new AuthenticationService;
        $auth->setStorage(new SessionStorage("EMISSAO_CERTIFICADOS"));
        $pessoa = $auth->getIdentity();

        $id_crypt = $this->params()->fromRoute('id', '0');
        $id = Util::decrypt($id_crypt);
        $evento = $this->getEm()->getRepository('Certificados\Entity\Evento')->findOneByEventoId($id);
        if ($evento && $this->permitidoAcessar($pessoa, $evento)) {
            $array = array();
            $array["participantes"] = $this->getEm()->getRepository('Certificados\Entity\Inscricao')->findInscricoesCredenciadas($id);
            $array["colaboradores"] = $this->getEm()->getRepository('Certificados\Entity\Comissao')->findColaboradores($id);
            $array["organizadores"] = $this->getEm()->getRepository('Certificados\Entity\Comissao')->findCoordenadores($id);

            $service = $this->getServiceLocator()->get('Certificados\Service\EmissaoService');
            if ($evento->getEveDisponivelEmissao()) {
                if ($this->getRequest()->isPost()) {
                    $data = $this->getRequest()->getPost()->toArray();
                    $novo_array = $this->removerConflitos($array, $data);
                    if ($this->verificarConflito($novo_array)) {

                        return new ViewModel(array('mensagem' => true, 'sucesso' => false));
                    } else {
                        if ($service->emitirCertificados($novo_array, $id)) {
                            return new ViewModel(array('mensagem' => true, 'sucesso' => true));
                        } else {
                            return new ViewModel(array('mensagem' => true, 'sucesso' => false));
                        }
                    }
                } else {
                    $conflitos = $this->verificarConflito($array);
                    if (!$conflitos) {
                        $service->emitirCertificados($array, $id);
//                    $this->redirect()->toRoute('certificados/emissao');
                        return new ViewModel(array('mensagem' => true, 'sucesso' => true));
                    } else {
                        return new ViewModel(array('mensagem' => false, 'conflitos' => $conflitos, 'evento' => $evento));
                    }
                }
            } else {
                $this->redirect()->toRoute('certificados/emissao');
            }
        } else {
            $this->redirect()->toRoute("certificados/emissao");
        }
    }

    public function verificarConflito($array) {
        $conflitos = array();
        foreach ($array["participantes"] as $item) {
            $conflitos[$item["inscricao"]->getPessoa()->getPessoaId()]["pessoa"] = $item["inscricao"]->getPessoa();
            $conflitos[$item["inscricao"]->getPessoa()->getPessoaId()]["participante"] = $item;
        }
        foreach ($array["colaboradores"] as $item) {
            $conflitos[$item->getPessoa()->getPessoaId()]["pessoa"] = $item->getPessoa();
            $conflitos[$item->getPessoa()->getPessoaId()]["colaborador"] = $item;
        }

        foreach ($array["organizadores"] as $item) {
            $conflitos[$item->getPessoa()->getPessoaId()]["pessoa"] = $item->getPessoa();
            $conflitos[$item->getPessoa()->getPessoaId()]["organizador"] = $item;
        }
        foreach ($conflitos as $key => $item) {
            if (count($item) == 2) {
                unset($conflitos[$key]);
            }
        }
        return $conflitos;
    }

    public function removerConflitos($array_completo, $array_alteracoes) {
        foreach ($array_alteracoes["pessoa"] as $key => $value) {
            $id = Util::decrypt(strval($key));

            if ($value == 'c') {
                unset($array_completo["participantes"][$id]);
                unset($array_completo["organizadores"][$id]);
                unset($array_completo["ministrantes"][$id]);
            } else if ($value == 'p') {
                unset($array_completo["colaboradores"][$id]);
                unset($array_completo["organizadores"][$id]);
                unset($array_completo["ministrantes"][$id]);
            } else if ($value == "o") {
                unset($array_completo["participantes"][$id]);
                unset($array_completo["colaboradores"][$id]);
                unset($array_completo["ministrantes"][$id]);
            } else if ($value == "m") {
                unset($array_completo["participantes"][$id]);
                unset($array_completo["organizadores"][$id]);
                unset($array_completo["colaboradores"][$id]);
            } else {
                $this->redirect()->toRoute('certificados/emissao', array('action' => 'erro'));
            }
        }
        return $array_completo;
    }

    public function permitidoAcessar($pessoa, $evento) {
        $retorno = false;
        $em = $this->getServiceLocator()->get('Doctrine\ORM\EntityManager');
        $eventos_disponiveis_pessoa = $em->getRepository('Certificados\Entity\Comissao')->findEventosDisponiveisByPessoa($pessoa);
        foreach ($eventos_disponiveis_pessoa["eventos"] as $evento_disponivel) {
            if ($evento->getEventoId() == $evento_disponivel->getEventoId()) {
                $retorno = true;
            }
        }
        return $retorno;
    }

    public function carregarSelects() {
        $array = array();

        $array["pessoas"] = array("" => "Selecione um participante");
        $pessoas = $this->getEm()->getRepository('Certificados\Entity\Pessoa')->findAll();
        foreach ($pessoas as $pessoa) {
            $array["pessoas"][$pessoa->getPessoaId()] = $pessoa->getPesNome();
        }

        $array["eventos"] = array("" => "Selecione um evento");
        $eventos = $this->getEm()->getRepository('Certificados\Entity\Evento')->findAll();
        foreach ($eventos as $evento) {
            $array["eventos"][$evento->getEventoId()] = $evento->getEveNome();
        }

        $array["tipos_participante"] = array("" => "Selecione o tipo do participante");
        $tipos_participante = $this->getEm()->getRepository('Certificados\Entity\ParticipanteTipo')->findAll();
        foreach ($tipos_participante as $tipo_participante) {
            $array["tipos_participante"][$tipo_participante->getParticipanteTipoId()] = $tipo_participante->getPartSubstantivo();
        }
        $array["modos"] = array("" => "Selecione o modo do certificado");
        $modos = $this->getEm()->getRepository('Certificados\Entity\Modo')->findAll();
        foreach ($modos as $modo) {
            $array["modos"][$modo->getModoId()] = $modo->getModDescricao();
        }
        $array["modelos"] = array("" => "Selecione um modelo de certificado");
        $modelos = $this->getEm()->getRepository('Certificados\Entity\CertificadoModelo')->findAll();
        foreach ($modelos as $modelo) {
            $array["modelos"][$modelo->getId()] = $modelo->getDescricao();
        }
        return $array;
    }

    public function manualAction() {
        $auth = new AuthenticationService;
        $auth->setStorage(new SessionStorage("EMISSAO_CERTIFICADOS"));
        $pessoa = $auth->getIdentity();
        $request = $this->getRequest();

        $form = new \Certificados\Form\EmissaoManual("consulta-manual", $this->carregarSelects());
        if ($request->isPost()) {
            $data = $request->getPost();
            $form->setData($data);
            if($form->isValid()){
                $service = $this->getServiceLocator()->get('Certificados\Service\EmissaoService');
                $service->emitirCertificadoManual($data->toArray());
                $this->redirect()->toRoute("certificados"); 
            }
        }
        return new ViewModel(array("form" => $form));
    }

}
