<?php

namespace Certificados\Entity;

use DateTime;
use Doctrine\ORM\Mapping as ORM;

/**
 * Certificado
 *
 * @ORM\Table(name="certificado", uniqueConstraints={@ORM\UniqueConstraint(name="cod_protocolo_UNIQUE", columns={"cer_codigo_protocolo"})}, indexes={@ORM\Index(name="fk_pessoa_has_evento_evento2_idx", columns={"evento_id"}), @ORM\Index(name="fk_pessoa_has_evento_pessoa1_idx", columns={"pessoa_id"}), @ORM\Index(name="fk_certificado_tipo_participante1_idx", columns={"participante_tipo_id"}), @ORM\Index(name="fk_certificado_modo1_idx", columns={"modo_id"})})
 * @ORM\Entity
 * @ORM\Entity(repositoryClass="Certificados\Entity\CertificadoRepository")
 */
class Certificado {

    /**
     * @var integer
     *
     * @ORM\Column(name="certificado_id", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $certificadoId;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="cer_data_emissao", type="date", nullable=false)
     */
    private $cerDataEmissao;

    /**
     * @var string
     *
     * @ORM\Column(name="cer_chave_validacao", type="string", length=10, nullable=true)
     */
    private $cerChaveValidacao;

    /**
     * @var \Pessoa
     *
     * @ORM\GeneratedValue(strategy="NONE")
     * @ORM\OneToOne(targetEntity="Pessoa")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="pessoa_id", referencedColumnName="pessoa_id")
     * })
     */
    private $pessoa;

    /**
     * @var \Evento
     * 
     * @ORM\GeneratedValue(strategy="NONE")
     * @ORM\OneToOne(targetEntity="Evento")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="evento_id", referencedColumnName="evento_id")
     * })
     */
    private $evento;

    /**
     * @var \ParticipanteTipo
     *
     * @ORM\ManyToOne(targetEntity="ParticipanteTipo")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="participante_tipo_id", referencedColumnName="participante_tipo_id")
     * })
     */
    private $participanteTipo;

    /**
     * @var \Modo
     *
     * @ORM\ManyToOne(targetEntity="Modo")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="modo_id", referencedColumnName="modo_id")
     * })
     */
    private $modo;

    /**
     * @var integer
     *
     * @ORM\Column(name="cer_carga_horaria_total", type="integer", nullable=true)
     */
    private $cerCargaHorariaTotal;

    /**
     * @var \Doctrine\Common\Collections\Collection
     *
     * @ORM\ManyToMany(targetEntity="Certificados\Entity\EventoSecundario", inversedBy="evento_secundario")
     * @ORM\JoinTable(name="certificado_evento_secundario",
     *   joinColumns={
     *     @ORM\JoinColumn(name="certificado_id", referencedColumnName="certificado_id")
     *   },
     *   inverseJoinColumns={
     *     @ORM\JoinColumn(name="evento_secundario_id", referencedColumnName="evento_secundario_id")
     *   }
     * )
     */
    private $eventoSecundario;
    
    /**
     * @var string
     *
     * @ORM\Column(name="cer_titulo", type="text", nullable=true)
     */
    private $cerTitulo;
    
    /**
     * @var string
     *
     * @ORM\Column(name="cer_outras_pessoas", type="text", nullable=true)
     */
    private $cerOutrasPessoas;
    
    /**
     * @var integer
     *
     * @ORM\Column(name="cer_colocacao", type="integer", nullable=true)
     */
    private $cerColocacao;
    
    /**
     * @var string
     *
     * @ORM\Column(name="cer_categoria", type="text", nullable=true)
     */
    private $cerCategoria;
    
    /**
     * @var \CertificadoModelo
     *
     * @ORM\ManyToOne(targetEntity="CertificadoModelo")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="certificado_modelo_id", referencedColumnName="id")
     * })
     */
    private $certificadoModelo;

    public function getCerDataEmissao() {
        return $this->cerDataEmissao;
    }

    public function getCerChaveValidacao() {
        return $this->cerChaveValidacao;
    }

    public function getPessoa() {
        return $this->pessoa;
    }

    public function getEvento() {
        return $this->evento;
    }

    public function getParticipanteTipo() {
        return $this->participanteTipo;
    }

    public function getModo() {
        return $this->modo;
    }

    public function setCerDataEmissao(\DateTime $cerDataEmissao) {
        $this->cerDataEmissao = new DateTime("now");
        return $this;
    }

    public function setCerChaveValidacao($cerChaveValidacao) {
        $this->cerChaveValidacao = $cerChaveValidacao;
        return $this;
    }

    public function setPessoa($pessoa) {
        $this->pessoa = $pessoa;
        return $this;
    }

    public function setEvento($evento) {
        $this->evento = $evento;
        return $this;
    }

    public function setParticipanteTipo($participanteTipo) {
        $this->participanteTipo = $participanteTipo;
        return $this;
    }

    public function setModo($modo) {
        $this->modo = $modo;
        return $this;
    }

    public function getCerCargaHorariaTotal() {
        return $this->cerCargaHorariaTotal;
    }

    public function setCerCargaHorariaTotal($cerCargaHorariaTotal) {
        $this->cerCargaHorariaTotal = $cerCargaHorariaTotal;
        return $this;
    }

    public function getCertificadoId() {
        return $this->certificadoId;
    }

    public function getEventoSecundario() {
        return $this->eventoSecundario;
    }

    public function setCertificadoId($certificadoId) {
        $this->certificadoId = $certificadoId;
        return $this;
    }

    public function setEventoSecundario($eventoSecundario) {
        $this->eventoSecundario = $eventoSecundario;
        return $this;
    }
    
    
    public function getCerTitulo() {
        return $this->cerTitulo;
    }

    public function getCerOutrasPessoas() {
        return $this->cerOutrasPessoas;
    }

    public function getCerColocacao() {
        return $this->cerColocacao;
    }

    public function getCerCategoria() {
        return $this->cerCategoria;
    }

    public function getCertificadoModelo() {
        return $this->certificadoModelo;
    }

    public function setCerTitulo($cerTitulo) {
        $this->cerTitulo = $cerTitulo;
        return $this;
    }

    public function setCerOutrasPessoas($cerOutrasPessoas) {
        $this->cerOutrasPessoas = $cerOutrasPessoas;
        return $this;
    }

    public function setCerColocacao($cerColocacao) {
        $this->cerColocacao = $cerColocacao;
        return $this;
    }

    public function setCerCategoria($cerCategoria) {
        $this->cerCategoria = $cerCategoria;
        return $this;
    }

    public function setCertificadoModelo($certificadoModelo) {
        $this->certificadoModelo = $certificadoModelo;
        return $this;
    }

    
    
    public function __construct() {
        $this->cerDataEmissao = new DateTime("now");
        $this->cerCodigoProtocolo = "padrao";
    }

}
