<?php

namespace Certificados\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * Evento
 *
 * @ORM\Table(name="evento", uniqueConstraints={@ORM\UniqueConstraint(name="eve_alias_UNIQUE", columns={"eve_alias"})}, indexes={@ORM\Index(name="fk_evento_evento_tipo1_idx", columns={"evento_tipo_id"}), @ORM\Index(name="fk_evento_unidade_ensino1_idx", columns={"unidade_ensino_id"}), @ORM\Index(name="fk_evento_local1_idx", columns={"local_id"})})
 * @ORM\Entity
 * @ORM\Entity(repositoryClass="Certificados\Entity\EventoRepository")
 */
class Evento
{
    /**
     * @var integer
     *
     * @ORM\Column(name="evento_id", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $eventoId;

    /**
     * @var string
     *
     * @ORM\Column(name="eve_nome", type="string", length=150, nullable=false)
     */
    private $eveNome;

    /**
     * @var string
     *
     * @ORM\Column(name="eve_alias", type="string", length=100, nullable=false)
     */
    private $eveAlias;

    /**
     * @var string
     *
     * @ORM\Column(name="eve_descricao", type="text", nullable=false)
     */
    private $eveDescricao;

    /**
     * @var string
     *
     * @ORM\Column(name="eve_site", type="string", length=200, nullable=true)
     */
    private $eveSite;

    /**
     * @var boolean
     *
     * @ORM\Column(name="eve_unidade_ensino", type="boolean", nullable=false)
     */
    private $eveUnidadeEnsino = '1';

    /**
     * @var integer
     *
     * @ORM\Column(name="eve_vagas", type="integer", nullable=true)
     */
    private $eveVagas;

    /**
     * @var integer
     *
     * @ORM\Column(name="eve_carga_horaria", type="integer", nullable=true)
     */
    private $eveCargaHoraria;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="eve_inicio", type="datetime", nullable=false)
     */
    private $eveInicio;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="eve_fim", type="datetime", nullable=false)
     */
    private $eveFim;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="eve_inicio_inscricao", type="datetime", nullable=false)
     */
    private $eveInicioInscricao;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="eve_fim_inscricao", type="datetime", nullable=false)
     */
    private $eveFimInscricao;

    /**
     * @var string
     *
     * @ORM\Column(name="eve_foto", type="text", nullable=true)
     */
    private $eveFoto;

    /**
     * @var integer
     *
     * @ORM\Column(name="eve_submissao_arquivo", type="integer", nullable=true)
     */
    private $eveSubmissaoArquivo = '0';

    
    /**
     * @var \EventoTipo
     *
     * @ORM\ManyToOne(targetEntity="EventoTipo")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="evento_tipo_id", referencedColumnName="evento_tipo_id")
     * })
     */
    private $eventoTipo;

    /**
     * @var \UnidadeEnsino
     *
     * @ORM\ManyToOne(targetEntity="UnidadeEnsino")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="unidade_ensino_id", referencedColumnName="unidade_ensino_id")
     * })
     */
    private $unidadeEnsino;

    /**
     * @var \Local
     *
     * @ORM\ManyToOne(targetEntity="Local")
     * @ORM\JoinColumns({
     *   @ORM\JoinColumn(name="local_id", referencedColumnName="local_id")
     * })
     */
    private $local;

    /**
     * @var \Pessoa
     *
     * @ORM\ManyToMany(targetEntity="Certificados\Entity\Pessoa", inversedBy="evento")
     * @ORM\JoinTable(name="comissao",
     *   joinColumns={
     *     @ORM\JoinColumn(name="evento_id", referencedColumnName="evento_id")
     *   },
     *   inverseJoinColumns={
     *     @ORM\JoinColumn(name="pessoa_id", referencedColumnName="pessoa_id")
     *   }
     * )
     */
    private $pessoa;
    
   
    /**
     * @var boolean
     *
     * @ORM\Column(name="eve_disponivel_emissao", type="boolean", nullable=false)
     */
    private $eveDisponivelEmissao = '0';
    
    
    public function getEventoId() {
        return $this->eventoId;
    }

    public function getEveNome() {
        return $this->eveNome;
    }

    public function getEveAlias() {
        return $this->eveAlias;
    }

    public function getEveDescricao() {
        return $this->eveDescricao;
    }

    public function getEveSite() {
        return $this->eveSite;
    }

    public function getEveUnidadeEnsino() {
        return $this->eveUnidadeEnsino;
    }

    public function getEveVagas() {
        return $this->eveVagas;
    }

    public function getEveCargaHoraria() {
        return $this->eveCargaHoraria;
    }

    public function getEveInicio() {
        return $this->eveInicio;
    }

    public function getEveFim() {
        return $this->eveFim;
    }

    public function getEveInicioInscricao() {
        return $this->eveInicioInscricao;
    }

    public function getEveFimInscricao() {
        return $this->eveFimInscricao;
    }

    public function getEveFoto() {
        return $this->eveFoto;
    }

    public function getEveSubmissaoArquivo() {
        return $this->eveSubmissaoArquivo;
    }

    public function getEventoTipo() {
        return $this->eventoTipo;
    }

    public function getUnidadeEnsino() {
        return $this->unidadeEnsino;
    }

    public function getLocal() {
        return $this->local;
    }

    public function getPessoa() {
        return $this->pessoa;
    }

    public function setEventoId($eventoId) {
        $this->eventoId = $eventoId;
        return $this;
    }

    public function setEveNome($eveNome) {
        $this->eveNome = $eveNome;
        return $this;
    }

    public function setEveAlias($eveAlias) {
        $this->eveAlias = $eveAlias;
        return $this;
    }

    public function setEveDescricao($eveDescricao) {
        $this->eveDescricao = $eveDescricao;
        return $this;
    }

    public function setEveSite($eveSite) {
        $this->eveSite = $eveSite;
        return $this;
    }

    public function setEveUnidadeEnsino($eveUnidadeEnsino) {
        $this->eveUnidadeEnsino = $eveUnidadeEnsino;
        return $this;
    }

    public function setEveVagas($eveVagas) {
        $this->eveVagas = $eveVagas;
        return $this;
    }

    public function setEveCargaHoraria($eveCargaHoraria) {
        $this->eveCargaHoraria = $eveCargaHoraria;
        return $this;
    }

    public function setEveInicio(\DateTime $eveInicio) {
        $this->eveInicio = $eveInicio;
        return $this;
    }

    public function setEveFim(\DateTime $eveFim) {
        $this->eveFim = $eveFim;
        return $this;
    }

    public function setEveInicioInscricao(\DateTime $eveInicioInscricao) {
        $this->eveInicioInscricao = $eveInicioInscricao;
        return $this;
    }

    public function setEveFimInscricao(\DateTime $eveFimInscricao) {
        $this->eveFimInscricao = $eveFimInscricao;
        return $this;
    }

    public function setEveFoto($eveFoto) {
        $this->eveFoto = $eveFoto;
        return $this;
    }

    public function setEveSubmissaoArquivo($eveSubmissaoArquivo) {
        $this->eveSubmissaoArquivo = $eveSubmissaoArquivo;
        return $this;
    }

    public function setEventoTipo($eventoTipo) {
        $this->eventoTipo = $eventoTipo;
        return $this;
    }

    public function setUnidadeEnsino($unidadeEnsino) {
        $this->unidadeEnsino = $unidadeEnsino;
        return $this;
    }

    public function setLocal($local) {
        $this->local = $local;
        return $this;
    }

    public function setPessoa($pessoa) {
        $this->pessoa = $pessoa;
        return $this;
    }

     public function getEveDisponivelEmissao() {
        return $this->eveDisponivelEmissao;
    }

    public function setEveDisponivelEmissao($eveDisponivelEmissao) {
        $this->eveDisponivelEmissao = $eveDisponivelEmissao;
        return $this;
    }

            
        /**
     * Constructor
     */
    public function __construct()
    {
        $this->pessoa = new \Doctrine\Common\Collections\ArrayCollection();
    }

}
