<?php

namespace Certificados\Entity;

use Doctrine\ORM\Mapping as ORM;

/**
 * Pessoa
 *
 * @ORM\Table(name="pessoa", uniqueConstraints={@ORM\UniqueConstraint(name="pes_email_UNIQUE", columns={"pes_email"}), @ORM\UniqueConstraint(name="pes_cpf_UNIQUE", columns={"pes_cpf"})})
 * @ORM\Entity
 * @ORM\Entity(repositoryClass="Certificados\Entity\PessoaRepository")
 */
class Pessoa
{
    /**
     * @var integer
     *
     * @ORM\Column(name="pessoa_id", type="integer", nullable=false)
     * @ORM\Id
     * @ORM\GeneratedValue(strategy="IDENTITY")
     */
    private $pessoaId;

    /**
     * @var string
     *
     * @ORM\Column(name="pes_nome", type="string", length=100, nullable=false)
     */
    private $pesNome;

    /**
     * @var string
     *
     * @ORM\Column(name="pes_email", type="string", length=100, nullable=false)
     */
    private $pesEmail;

    /**
     * @var string
     *
     * @ORM\Column(name="pes_telefone", type="string", length=14, nullable=false)
     */
    private $pesTelefone;

    /**
     * @var string
     *
     * @ORM\Column(name="pes_celular", type="string", length=14, nullable=true)
     */
    private $pesCelular;

    /**
     * @var \DateTime
     *
     * @ORM\Column(name="pes_data_nascimento", type="date", nullable=false)
     */
    private $pesDataNascimento;

    /**
     * @var string
     *
     * @ORM\Column(name="pes_login", type="string", length=45, nullable=false)
     */
    private $pesLogin;

    /**
     * @var string
     *
     * @ORM\Column(name="pes_senha", type="string", length=512, nullable=false)
     */
    private $pesSenha;

    /**
     * @var integer
     *
     * @ORM\Column(name="pes_cpf", type="bigint", nullable=false)
     */
    private $pesCpf;

    /**
     * @var \Doctrine\Common\Collections\Collection
     *
     * @ORM\ManyToMany(targetEntity="Evento", mappedBy="pessoa")
     */
    private $evento;
    
    
    /**
     * @var \Evento
     *
     * @ORM\ManyToMany(targetEntity="Certificados\Entity\Evento", inversedBy="pessoa")
     * @ORM\JoinTable(name="comissao",
     *   joinColumns={
     *     @ORM\JoinColumn(name="pessoa_id", referencedColumnName="pessoa_id")
     *   },
     *   inverseJoinColumns={
     *     @ORM\JoinColumn(name="evento_id", referencedColumnName="evento_id")
     *   }
     * )
     */
    private $pesEventosComissao;

    public function getPessoaId() {
        return $this->pessoaId;
    }

    public function getPesNome() {
        return $this->pesNome; 
    }

    public function getPesEmail() {
        return $this->pesEmail;
    }

    public function getPesTelefone() {
        return $this->pesTelefone;
    }

    public function getPesCelular() {
        return $this->pesCelular;
    }

    public function getPesDataNascimento() {
        return $this->pesDataNascimento;
    }

    public function getPesLogin() {
        return $this->pesLogin;
    }

    public function getPesSenha() {
        return $this->pesSenha;
    }

    public function getPesCpf() {
        return $this->pesCpf;
    }

    public function getEvento() {
        return $this->evento;
    }

    public function setPessoaId($pessoaId) {
        $this->pessoaId = $pessoaId;
    }

    public function setPesNome($pesNome) {
        $this->pesNome = $pesNome;
    }

    public function setPesEmail($pesEmail) {
        $this->pesEmail = $pesEmail;
    }

    public function setPesTelefone($pesTelefone) {
        $this->pesTelefone = $pesTelefone;
    }

    public function setPesCelular($pesCelular) {
        $this->pesCelular = $pesCelular;
    }

    public function setPesDataNascimento(\DateTime $pesDataNascimento) {
        $this->pesDataNascimento = $pesDataNascimento;
    }

    public function setPesLogin($pesLogin) {
        $this->pesLogin = $pesLogin;
    }

    public function setPesSenha($pesSenha) {
        $this->pesSenha = $this->encryptPassword($pesSenha);
    }

    public function setPesCpf($pesCpf) {
        $this->pesCpf = $pesCpf;
    }

    public function setEvento(\Doctrine\Common\Collections\Collection $evento) {
        $this->evento = $evento;
    }

        
    /**
     * Constructor
     */
    public function __construct()
    {
        $this->evento = new \Doctrine\Common\Collections\ArrayCollection();
    }
    
    public function encryptPassword($senha){
        $senha_criptografada = sha1(md5($senha));
        for ($i = 1; $i < 100; $i++) {
            $senha_criptografada = sha1($senha_criptografada);
        }
        return $senha_criptografada;
    }
    
    
    function getPesEventosComissao() {
        return $this->pesEventosComissao;
    }

    function setPesEventosComissao($pesParteComissao) {
        $this->pesEventosComissao = $pesParteComissao;
        return $this;
    }


}
