<?php

namespace Certificados\Service;

use Certificados\Entity\Certificado;
use Certificados\Entity\Comissao;
use Certificados\Entity\EventoSecundario as EventoSecundario2;
use Certificados\Entity\Inscricao;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\ORM\EntityManager;
use DoctrineORMModule\Proxy\__CG__\Certificados\Entity\Evento;
use DoctrineORMModule\Proxy\__CG__\Certificados\Entity\EventoSecundario;
use DoctrineORMModule\Proxy\__CG__\Certificados\Entity\Modo;
use DoctrineORMModule\Proxy\__CG__\Certificados\Entity\ParticipanteTipo;

class EmissaoService {

    protected $em;

    public function __construct(EntityManager $em) {
        $this->em = $em;
    }

    public function calculaCargaHorariaByInscricao($inscricao) {
        $carga_horaria = 0;
        $eventos_secundarios = $this->em->getRepository('Certificados\Entity\EventoSecundario')->findByEvento($inscricao->getEvento()->getEventoId());
        if ($eventos_secundarios) {
            foreach ($inscricao->getInscricaoEventoSecundario() as $eventoSec) {
                if ($eventoSec->getInsesPresenca() && !$eventoSec->getInsesCancelada()) {
                    $carga_horaria += $eventoSec->getEventoSecundario()->getEvesCargaHoraria();
                }
            }
        } else {
            $carga_horaria = $inscricao->getEvento()->getEveCargaHoraria();
        }
        return $carga_horaria;
    }

    public function emitirCertificados($certificados, $evento_id) {
        $sucesso = false;
        $this->em->beginTransaction();
        $this->emitirCertificadosParticipantes($certificados["participantes"], $evento_id);
        $this->emitirCertificadosOrganizadores($certificados["organizadores"], $evento_id);
        $this->emitirCertificadosColaboradores($certificados["colaboradores"], $evento_id);
//        $this->emitirCertificadosMinistrantes($certificados["participantes"], $evento_id);

        $evento = $this->em->getReference('Certificados\Entity\Evento', $evento_id);
        if ($evento->getEveDisponivelEmissao()) {
            $evento->setEveDisponivelEmissao(false);
            $this->em->persist($evento);
            $this->em->flush();
            $this->em->commit();
            $sucesso = true;
        } else {
            $this->em->rollback();
        }
        return $sucesso;
    }

    public function emitirCertificadoManual($data) {
        
//        var_dump($data);
//        die;
        $pessoa = $this->em->getReference('Certificados\Entity\Pessoa', $data["pessoa"]);
        $evento = $this->em->getReference('Certificados\Entity\Evento', $data["evento"]);
        $tipo_participante = $this->em->getReference('Certificados\Entity\ParticipanteTipo', $data["tipo_participante"]);
        $modo = $this->em->getReference('Certificados\Entity\Modo', $data["modo"]);
        $modelo = $this->em->getReference('Certificados\Entity\CertificadoModelo', $data["modelo"]);
        $entity = new Certificado();
        $entity->setPessoa($pessoa);
        $entity->setEvento($evento);
        $entity->setParticipanteTipo($tipo_participante);
        $entity->setModo($modo);
        $entity->setCertificadoModelo($modelo);
        $entity->setCerCargaHorariaTotal($data["carga_horaria"]);
        if (isset($data["titulo"])) {
            $entity->setCerTitulo($data["titulo"]);
        }
        if (isset($data["outros"])) {
            $entity->setCerOutrasPessoas($data["outros"]);
        }
        if (isset($data["colocacao"])) {
            $entity->setCerColocacao($data["colocacao"]);
        }
        if (isset($data["categoria"])) {
            $entity->setCerCategoria($data["categoria"]);
        }
        $key = strtoupper(base_convert(sprintf("%d%d%d", $data["evento"], $data["pessoa"], time()), 10, 32));
        $entity->setCerChaveValidacao($key);
        $this->em->persist($entity);
        $this->em->flush();
    }

    public function emitirCertificadosParticipantes(array $certificados_participantes, $evento_id) {
        foreach ($certificados_participantes as $certificado_participante) {
            $entity = $this->getCertificadoParticipanteEntity($certificado_participante, $evento_id);
            if ($entity->getCerCargaHorariaTotal() == 0) {
                continue;
            }
            $this->em->persist($entity);
            $this->em->flush();
        }
    }

    public function emitirCertificadosOrganizadores(array $certificados_organizadores, $evento_id) {
        foreach ($certificados_organizadores as $certificado_organizador) {
            $entity = $this->getCertificadoOrganizadorEntity($certificado_organizador, $evento_id);
            if ($entity->getCerCargaHorariaTotal() == 0) {
                continue;
            }
            $this->em->persist($entity);
            $this->em->flush();
        }
    }

    public function emitirCertificadosColaboradores(array $certificados_colaboradores, $evento_id) {
        foreach ($certificados_colaboradores as $certificado_colaborador) {
            $entity = $this->getCertificadoColaboradorEntity($certificado_colaborador, $evento_id);
            if ($entity->getCerCargaHorariaTotal() == 0) {
                continue;
            }
            $this->em->persist($entity);
            $this->em->flush();
        }
    }

    public function getCertificadoParticipanteEntity(array $certificado, $evento_id) {
        $inscricao = $this->em->getRepository('Certificados\Entity\Inscricao')->findOneByInscricaoId($certificado["inscricao"]);
        $entity = new Certificado;
        $entity->setEvento($inscricao->getEvento());
        $entity->setPessoa($inscricao->getPessoa());
        $participante_tipo = $this->em->getReference('Certificados\Entity\ParticipanteTipo', 1);
        $entity->setParticipanteTipo($participante_tipo);

        $key = strtoupper(base_convert(sprintf("%d%d%d", $evento_id, $inscricao->getPessoa()->getPessoaId(), time()), 10, 32));
        $entity->setCerChaveValidacao($key);
        $entity->setCerCargaHorariaTotal($this->calculaCargaHorariaByInscricao($inscricao));
        $entity->setEventoSecundario($this->getColecaoEventosSecundariosComPresenca($inscricao));
        if ($entity->getCerCargaHorariaTotal() >= 20) {
            $modo = $this->em->getReference('Certificados\Entity\Modo', 2);
        } else {
            $modo = $this->em->getReference('Certificados\Entity\Modo', 1);
        }
        $entity->setModo($modo);
        return $entity;
    }

    public function getCertificadoOrganizadorEntity($certificado, $evento_id) {
        $membro_comissao = $this->em->getRepository('Certificados\Entity\Comissao')->findOneByPessoaEvento($certificado->getPessoa()->getPessoaId(), $evento_id);
        $entity = new Certificado;

        $entity->setEvento($membro_comissao[0]->getEvento());
        $entity->setPessoa($membro_comissao[0]->getPessoa());
        $participante_tipo = $this->em->getReference('Certificados\Entity\ParticipanteTipo', 2);
        $entity->setParticipanteTipo($participante_tipo);

        $key = strtoupper(base_convert(sprintf("%d%d%d", $evento_id, $certificado->getPessoa()->getPessoaId(), time()), 10, 32));
        $entity->setCerChaveValidacao($key);
        $entity->setCerCargaHorariaTotal($membro_comissao[0]->getComCargaHoraria());
        if ($entity->getCerCargaHorariaTotal() >= 20) {
            $modo = $this->em->getReference('Certificados\Entity\Modo', 2);
        } else {
            $modo = $this->em->getReference('Certificados\Entity\Modo', 1);
        }
        $entity->setModo($modo);
//        $entity->setEventoSecundario($this->getColecaoEventosSecundariosComPresenca($inscricao));
        return $entity;
    }

    public function getCertificadoColaboradorEntity($certificado, $evento_id) {
        $membro_comissao = $this->em->getRepository('Certificados\Entity\Comissao')->findOneByPessoaEvento($certificado->getPessoa()->getPessoaId(), $evento_id);
        $entity = new Certificado;
        $entity->setEvento($membro_comissao[0]->getEvento());
        $entity->setPessoa($membro_comissao[0]->getPessoa());
        $participante_tipo = $this->em->getReference('Certificados\Entity\ParticipanteTipo', 3);
        $entity->setParticipanteTipo($participante_tipo);

        $key = strtoupper(base_convert(sprintf("%d%d%d", $evento_id, $certificado->getPessoa()->getPessoaId(), time()), 10, 32));
        $entity->setCerChaveValidacao($key);
        $entity->setCerCargaHorariaTotal($membro_comissao[0]->getComCargaHoraria());
        if ($entity->getCerCargaHorariaTotal() >= 20) {
            $modo = $this->em->getReference('Certificados\Entity\Modo', 2);
        } else {
            $modo = $this->em->getReference('Certificados\Entity\Modo', 1);
        }
        $entity->setModo($modo);
//        $entity->setEventoSecundario($this->getColecaoEventosSecundariosComPresenca($inscricao));
        return $entity;
    }

//    public function getCertificadoMinistranteEntity(array $certificado, $evento_id) {
//        $membro_comissao = $this->em->getRepository(Comissao::class)->findOneByPessoaId($certificado["pessoa"]);
//        $entity = new Certificado;
//        $entity->setEvento($membro_comissao->getEvento());
//        $entity->setPessoa($membro_comissao->getPessoa());
//        $participante_tipo = $this->em->getReference(ParticipanteTipo::class, 2);
//        $entity->setParticipanteTipo($participante_tipo);
//
//        $key = strtoupper(base_convert(sprintf("%d%d%d", $evento_id, $certificado['pessoa'], time()), 10, 32));
//        $entity->setCerChaveValidacao($key);
//        $entity->setCerCargaHorariaTotal($membro_comissao->getComCargaHoraria());
////        $entity->setEventoSecundario($this->getColecaoEventosSecundariosComPresenca($inscricao));
//        return $entity;
//    }
//
//    public function getCertificadoEntity(array $certificado, $evento_id) {
//        $inscricao = $this->em->getRepository(Inscricao::class)->findOneByInscricaoId($certificado["inscricao"]);
//        $entity = new Certificado;
////        $evento = $this->em->getReference(Evento::class, $evento_id);
//        $entity->setEvento($inscricao->getEvento());
////        $pessoa = $this->em->getReference(Pessoa::class, $certificado['pessoa']);
//        $entity->setPessoa($inscricao->getPessoa());
//        $participante_tipo = $this->em->getReference(ParticipanteTipo::class, $certificado['participante_tipo']);
//        $entity->setParticipanteTipo($participante_tipo);
//
//        $key = strtoupper(base_convert(sprintf("%d%d%d", $evento_id, $certificado['pessoa'], time()), 10, 32));
//        $entity->setCerChaveValidacao($key);
//        $entity->setCerCargaHorariaTotal(Util::calculaCargaHorariaByInscricao($inscricao));
//        $entity->setEventoSecundario($this->getColecaoEventosSecundariosComPresenca($inscricao));
//        return $entity;
//    }

    public function getColecaoEventosSecundarios(array $eventos_id) {
        $eventos_secundarios = new ArrayCollection();
        foreach ($eventos_id as $evento_id) {
            $es = $this->em->getReference('Certificados\Entity\EventoSecundario', $evento_id);
            $eventos_secundarios->add($es);
        }
        return $eventos_secundarios;
    }

    public function getColecaoEventosSecundariosComPresenca($inscricao) {
        $eventos_secundarios = new ArrayCollection();
        foreach ($inscricao->getInscricaoEventoSecundario() as $insc_evento_secundario) {
            if ($insc_evento_secundario->getInsesPresenca() && !$insc_evento_secundario->getInsesCancelada()) {
                $eventos_secundarios->add($insc_evento_secundario->getEventoSecundario());
            }
        }
        return $eventos_secundarios;
    }

}
